// This are game-spcific info string for QT build of Adv580.
//
#define GAME "Adv580"
#define GAMEINFO "<b>" GAME "</b> " \
"is Mike Goetz's 1978 expansion of Dave Platt's Adv550, which was " \
"in turn based on the text ur-game Adventure " \
"(a.k.a. Collossal Cave) created by Will Crowther and Don Woods." \
"<br> <br>" \
"For more information on the complex family tree of Adventure " \
"versions, see Russel Dalenberg's Adventure Family tree " \
"(<a href='https://mipmip.org/advfamily.html'>" \
"https://mipmip.org/advfamily.html</a>)."
